pub struct OverviewRoot { /* private fields */ }Trait Implementations
Sourceimpl Debug for OverviewRoot
impl Debug for OverviewRoot
Sourceimpl SimpleComponent for OverviewRoot
impl SimpleComponent for OverviewRoot
Sourcefn update_view(
&self,
widgets: &mut Self::Widgets,
sender: ComponentSender<Self>,
)
fn update_view( &self, widgets: &mut Self::Widgets, sender: ComponentSender<Self>, )
Update the view to represent the updated model.
Sourcetype Init = OverviewRootInit
type Init = OverviewRootInit
The parameter used to initialize the component.
Sourcetype Input = OverviewRootInput
type Input = OverviewRootInput
The message type that the component accepts as inputs.
Sourcetype Output = OverviewRootOutput
type Output = OverviewRootOutput
The message type that the component provides as outputs.
Sourcetype Widgets = OverviewRootWidgets
type Widgets = OverviewRootWidgets
The type that’s used for storing widgets created for this component.
Sourcefn init(
init: Self::Init,
root: Self::Root,
sender: ComponentSender<Self>,
) -> ComponentParts<Self>
fn init( init: Self::Init, root: Self::Root, sender: ComponentSender<Self>, ) -> ComponentParts<Self>
Creates the initial model and view, docking it into the component.
Sourcefn update(&mut self, message: Self::Input, sender: ComponentSender<Self>)
fn update(&mut self, message: Self::Input, sender: ComponentSender<Self>)
Processes inputs received by the component.