pub struct SwitchRoot { /* private fields */ }Trait Implementations
Sourceimpl Debug for SwitchRoot
impl Debug for SwitchRoot
Sourceimpl SimpleComponent for SwitchRoot
impl SimpleComponent for SwitchRoot
Sourcefn update_view(
&self,
widgets: &mut Self::Widgets,
sender: ComponentSender<Self>,
)
fn update_view( &self, widgets: &mut Self::Widgets, sender: ComponentSender<Self>, )
Update the view to represent the updated model.
Sourcetype Init = SwitchRootInit
type Init = SwitchRootInit
The parameter used to initialize the component.
Sourcetype Input = SwitchRootInput
type Input = SwitchRootInput
The message type that the component accepts as inputs.
Sourcetype Output = SwitchRootOutput
type Output = SwitchRootOutput
The message type that the component provides as outputs.
Sourcetype Root = ApplicationWindow
type Root = ApplicationWindow
The top-level widget of the component.
Sourcetype Widgets = SwitchRootWidgets
type Widgets = SwitchRootWidgets
The type that’s used for storing widgets created for this component.
Sourcefn init(
init: Self::Init,
root: Self::Root,
sender: ComponentSender<Self>,
) -> ComponentParts<Self>
fn init( init: Self::Init, root: Self::Root, sender: ComponentSender<Self>, ) -> ComponentParts<Self>
Creates the initial model and view, docking it into the component.
Sourcefn update(&mut self, message: Self::Input, sender: ComponentSender<Self>)
fn update(&mut self, message: Self::Input, sender: ComponentSender<Self>)
Processes inputs received by the component.